@@ -11,9 +11,10 @@ from .... import gateway
 from . import api
 
 
-@api.route('/<string:env>/auth/request-token', methods=['POST'])
-@api.route('/auth/request-token', methods=['POST'])
-def request_token(env=None):
+@api.route('/<string:env>/auth/<string:path>', methods=['POST'])
+@api.route('/auth/<string:path>', methods=['POST'])
+@api.route('/auth', methods=['POST'])
+def ldap_auth(path=None, env=None):
     auth = request.authorization
     password = auth.password
     username = auth.username
@@ -25,9 +26,13 @@ def request_token(env=None):
     except (KeyError, ValueError):
         return not_found(service_code=SERVICE_CODE)
     else:
+        if not path:
+            uri = '/auth'
+        else:
+            uri = '/auth/{}'.format(path)
         result = gw.call(
             request.method,
-            '/{}'.format('auth/request-token'),
+            uri,
             headers=request.headers,
             auth=(username, password),
             params=params,
