@@ -18,7 +18,7 @@ from lxml import etree
 from spyne.model.fault import Fault
 
 from rest_client import RestClient
-from .consts import ADDRESS
+from .consts import ADDRESS, LOGS
 from .consts import API_REGISTRY
 from .consts import CONFIG
 from .consts import HOSTNAME
@@ -218,7 +218,7 @@ class Api(object):
             username = False
         else:
             username = verify_access(
-                headers['X-Real-Ip'],
+                headers.get('X-Real-Ip', {}),
                 token,
                 service=self.service,
                 path=ressource,
@@ -244,6 +244,7 @@ class Api(object):
         elif username and not isinstance(username, bool):
             auth = (username, auth[1])
         client = RestClient(url)
+        LOGS.logger.info((method, url))
         result = client.__call_url__(
             method,
             ressource,
